@@ -1,24 +1,19 @@
 package it.unimi.dsi.fastutil.io;
 
 /*		 
- * fastutil: Fast & compact type-specific collections for Java
+ * Copyright (C) 2005-2014 Sebastiano Vigna 
  *
- * Copyright (C) 2003-2011 Paolo Boldi and Sebastiano Vigna 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Lesser General Public License as published by the Free
- *  Software Foundation; either version 2.1 of the License, or (at your option)
- *  any later version.
- *
- *  This library is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
- *  for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License. 
  */
 
 import java.io.EOFException;
@@ -80,7 +75,8 @@ public class FastMultiByteArrayInputStream extends MeasurableInputStream impleme
 
 		for( int i = 0; i < array.length; i++ ) {
 			array[ i ] = new byte[ size >= SLICE_SIZE ? SLICE_SIZE : (int)size ];
-			if ( is.read( array[ i ] ) != array[ i ].length ) throw new EOFException();
+			// It is important *not* to use is.read() directly because of bug #6478546
+			if ( BinIO.loadBytes( is, array[ i ] ) != array[ i ].length ) throw new EOFException();
 			size -= array[ i ].length;
 		}
 	}
